@@ -6,14 +6,12 @@
 #include <string.h>
 #include "utils.h"
 
-#ifdef ENABLE_SSE
+#if defined(ENABLE_SSE) && !defined(APPLE_PPC)
 #include "sse.h"
 #endif
 
 namespace _sbsms_ {
 
-typedef float t_fft[2];
-
 typedef void (*fftplan)(t_fft *x);
 void fft128(t_fft *x);
 void ifft128(t_fft *x);
@@ -21,8 +19,6 @@ void fft256(t_fft *x);
 void ifft256(t_fft *x);
 void fft384(t_fft *x);
 void fft512(t_fft *x);
-void fftr384(t_fft *x);
-void fftr512(t_fft *x);
 
 template<int N>
 class Factor {
@@ -326,7 +322,7 @@ public:
   }
 };
 
-#ifdef ENABLE_SSE
+#if defined(ENABLE_SSE) && !defined(APPLE_PPC)
 
 template <int N, int dir> 
 class SSETwiddles {
@@ -852,38 +848,6 @@ void fft(t_fft *x) {
   fft_reorder<N,dir>::reorder(x);
 }
 
-template<int N, int dir>
-void fftr(t_fft *x) {
-  enum { Nover2 = N/2,
-         Nover4 = N/4,
-         radix = Factor<Nover2>::value, 
-         stride = Nover2 / radix };
-  static const FloatTwiddles<N,dir> t;
-  static const float *s = t.s;
-  static const float *c = t.c;
-  for(int k=0; k<Nover2; k++) {
-    int k2 = k<<1;
-    x[k][0] = x[k2][0];
-    x[k][1] = x[k2+1][0];
-  }
-  _fft<0,stride,radix,dir>::execute(x);
-  fft_reorder<Nover2,dir>::reorder(x);
-  for(int k=1;k<Nover4;k++) {
-    int Nk = Nover2-k;
-    float k0 = 0.5f * (x[k][0] + x[Nk][0]);
-    float k1 = 0.5f * (x[k][1] - x[Nk][1]);
-    float Nk0 = 0.5f * (x[k][1] + x[Nk][1]);
-    float Nk1 = 0.5f * (x[Nk][0] - x[k][0]);
-
-    x[k][0] = k0 + c[k] * Nk0 - s[k] * Nk1;
-    x[k][1] = k1 + c[k] * Nk1 + s[k] * Nk0;
-    x[Nk][0] = k0 - c[k] * Nk0 + s[k] * Nk1;
-    x[Nk][1] = -k1 + c[k] * Nk1 + s[k] * Nk0;
-  }
-  x[0][0] = x[0][0] + x[0][1];
-  x[0][1] = 0.0f;
-}
-
 }
 
 #endif
