@@ -5,31 +5,19 @@
 #ifdef MULTITHREADED
 #include <pthread.h>
 #endif
+#include <stdlib.h>
 #include <string.h>
 #include <algorithm>
 using namespace std;
 
 namespace _sbsms_ {
 
-/*
-const SBSMSQualityParams SBSMSQualityStandard = {
-  8,3,
-  {512,512,384,384,384,384,384,384,0,0},
-  {168,144,128,108,84,44,24,14,0,0},
-  {384,288,256,168,128,84,52,28,0,0},
-  {512,448,360,288,228,132,84,44,0,0},
-  {1,1,2,1,1,2,1,1,0,0}
-};
-*/
-
 const SBSMSQualityParams SBSMSQualityStandard = {
   8,3,
   {512,512,384,384,384,384,384,384,0,0},
   {168,144,128,96,64,36,24,14,0,0},
   {384,288,256,168,128,84,52,28,0,0},
-  //{512,448,360,288,180,108,76,44,0,0},
   {512,448,360,288,192,128,84,44,0,0},
-  //{1,1,2,1,2,1,1,1,0,0}
   {1,1,2,1,1,2,1,1,0,0}
 };
 
