@@ -2,6 +2,7 @@
 #include "real.h"
 #include "utils.h"
 #include "dBTable.h"
+#include <stdlib.h>
 #include <math.h>
 #include <set>
 using namespace std;
@@ -113,8 +114,8 @@ SMS :: SMS(SMS *lo, int N, int band, int bandMax, int h, int res, int N0, int N1
   h2cum = 0.0;
   adjust2time = 0;
   adjust1time = 0;
-  trial2GrainBuf = new GrainBuf(N,h,N1,hannpoisson,channels==1);
-  trial1GrainBuf = new GrainBuf(N,h,N0,hannpoisson,channels==1);
+  trial2GrainBuf = new GrainBuf(N,h,N1,hannpoisson);
+  trial1GrainBuf = new GrainBuf(N,h,N0,hannpoisson);
   peak20 = (float*)calloc(2*N,sizeof(float));
   peak2N = peak20 + N;
   for(int k=-Nover2;k<=Nover2;k++) {
@@ -238,6 +239,7 @@ void SMS :: trial2(int c)
       if(band >= minTrial2Band) {
         float f = M;
         t->updateFPH(trial2time[c],synthModeTrial2,h,f,f);
+        t->synth(trial2Buf[c]+(trial2time[c]&resMask)*h,trial2time[c],h,synthModeTrial2,c);
       }
     } else {
       break;
@@ -498,14 +500,10 @@ void SMS :: adjust(GrainBuf *trialGrainBuf,
   for(int c=0; c<channels; c++) {    
     Slice *slice = slices[c];
     TrackPoint *p = slice->bottom;
-    if(channels == 2) {
-      if(c == 0) {
-        c2even(g->x, x1[0], N);
-      } else {
-        c2odd(g->x, x1[1], N);
-      }
+    if(c == 0) {
+      c2even(g->x, x1[0], N);
     } else {
-      memcpy(x1[0],g->x,(N+2)*sizeof(float));
+      c2odd(g->x, x1[1], N);
     }
     float *mag1 = _mag1[c];
     calcmags(mag1, x1[c]);
@@ -1254,7 +1252,7 @@ void SMS :: start(long offset, int c)
         ++tt;
         assignTracks[c].erase(eraseMe);
         returnTrackIndex(c,t);
-        t->disconnect();
+        t->absorb();
         delete t;
         continue;
       }
@@ -1292,7 +1290,6 @@ void SMS :: start(long offset, int c)
     TrackPoint *tpn = tp->pn;
     if(tp->bOwned) {
       if(tp->bDelete) {
-        tp->disconnect();
         tp->destroy();
       }
     } else {
@@ -1301,7 +1298,6 @@ void SMS :: start(long offset, int c)
       for(int d=0;d<2;d++) {
         TrackPoint *dup = tp->dup[d];
         if(dup && !dup->owner) {
-          dup->disconnect();
           dup->destroy();
         }
       }
@@ -1347,7 +1343,7 @@ void SMS :: splitMerge(int c)
         tp->cont = minH;
       }
     }
-    if(1&&tp->cont) {
+    if(tp->cont) {
       tp->owner->point.insert(tp->owner->point.begin(),tp->cont);
       tp->owner->first--;
       tp->owner->bStitch = true;
@@ -1383,7 +1379,7 @@ void SMS :: splitMerge(int c)
         tp->cont = minH;
       }
     }
-    if(1&&tp->cont) {
+    if(tp->cont) {
       tp->owner->point.insert(tp->owner->point.end(),tp->cont);
       tp->owner->last++;
       tp->owner->bStitch = true;
@@ -1412,32 +1408,22 @@ void SMS :: advance(int c)
 
 void SMS :: add(grain *g0, grain *g1, grain *g2, int c)
 {
-  if(channels == 2) {
-    if(c == 0) {
-      if(band >= minTrial1Band) {
-        c2even(g0->x, x00[0], N);
-      }
-      if(band >= minTrial2Band) {
-        c2even(g1->x, x10[0], N);
-      }
-      c2even(g2->x, x2[0], N);
-    } else {
-      if(band >= minTrial1Band) {
-        c2odd(g0->x, x00[1], N);
-      }
-      if(band >= minTrial2Band) {
-        c2odd(g1->x, x10[1], N);
-      }
-      c2odd(g2->x, x2[1], N);
-    }
-  } else {
+  if(c == 0) {
     if(band >= minTrial1Band) {
-      memcpy(x00[0],g0->x,(N+2)*sizeof(float));
+      c2even(g0->x, x00[0], N);
     }
     if(band >= minTrial2Band) {
-      memcpy(x10[0],g1->x,(N+2)*sizeof(float));
+      c2even(g1->x, x10[0], N);
     }
-    memcpy(x2[0],g2->x,(N+2)*sizeof(float));
+    c2even(g2->x, x2[0], N);
+  } else {
+    if(band >= minTrial1Band) {
+      c2odd(g0->x, x00[1], N);
+    }
+    if(band >= minTrial2Band) {
+      c2odd(g1->x, x10[1], N);
+    }
+    c2odd(g2->x, x2[1], N);
   }
 
   float *mag0;
@@ -1481,6 +1467,7 @@ void SMS :: add(grain *g0, grain *g1, grain *g2, int c)
   bool bX0 = !lo;
   bool bX1 = false;
   TrackPoint *prev = NULL;
+
   Slice *slice = new Slice(band,addtime[c]);
 
   for(int k=1; k<=kEnd; k++) {
@@ -1499,6 +1486,7 @@ void SMS :: add(grain *g0, grain *g1, grain *g2, int c)
         }
       } else {
         TrackPoint *p = new TrackPoint(slice,peak2N,x2[c],mag2,mag2,k,N,band);
+
         if(prev) {
           prev->pn = p;
           p->pp = prev;
@@ -1516,6 +1504,8 @@ void SMS :: add(grain *g0, grain *g1, grain *g2, int c)
       }
     } else if(mag2[k] <= mag2[k-1] && mag2[k] <= mag2[k+1]) {
       xt2 = findExtremum(mag2,mag2,k,NULL);
+      xt2 = max(1.0f,xt2);
+      xt2 = min((float)kEnd,xt2);
       if(bTroughN2) {
         prev->xtn2 = xt2;
         bTroughN2 = false;
@@ -1523,10 +1513,10 @@ void SMS :: add(grain *g0, grain *g1, grain *g2, int c)
     }
   }
   if(bTroughN2) {
-     prev->xtn2 = (float)kEnd;
+    prev->xtn2 = (float)kEnd;
   }
   if(!bX1 && !hi) {
-     x1 = (float)kEnd;
+    x1 = (float)kEnd;
     y1 = mag2[kEnd];
     bX1 = true;
   }
@@ -1678,7 +1668,8 @@ void SMS :: add(grain *g0, grain *g1, grain *g2, int c)
       p; ) {
     TrackPoint *pn = p->pn;
     if(p->m2 < m2min) {
-      p->disconnect();
+      if(p->m2 < 0) { p->m2 = 0; }
+      p->absorb();
       delete p;
     }
     p = pn;
@@ -1722,7 +1713,7 @@ Track *SMS :: createTrack(int c, TrackPoint *tp, const TimeType &time, bool bSti
     index = trackIndex[c].front();
     trackIndex[c].pop();
   }
-  Track *t = new Track((float)h1,index,tp,time,bStitch);
+  Track *t = new Track(h1,index,tp,time,bStitch);
   assignTracks[c].push_back(t);
   return t;
 }
